@@ -56,3 +56,11 @@ def set_contact_for_deal(deal_id, contact_id):
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to set contact for deal. Result: {result}")
   return result
+
+
+def set_deal_for_line_item(line_item_id, deal_id):
+  post_url = f"{BASE_URL}crm/v3/objects/line_items/{line_item_id}/associations/deals/{deal_id}/LINE_ITEM_TO_DEAL"
+  result = put(post_url, HEADERS)
+  if not Utils.is_success(result['status_code']):
+    raise Exception(f"Failed to set deal for line item. Result: {result}")
+  return result
