@@ -1,6 +1,7 @@
 from ..HTTP.Requests import *
 from .hubspot import BASE_URL
 from .hubspot import HEADERS
+from . import object_properties
 
 
 def search_contacts_by_property_value(property_name, property_value, property_names=None, after=None):
@@ -101,6 +102,17 @@ def create_contact(properties):
   return result
 
 
+def create_contacts_batch(contacts):
+  post_url = f"{BASE_URL}crm/v3/objects/contacts/batch/create"
+  post_body = {
+      'inputs': contacts
+  }
+  result = post(post_url, HEADERS, json.dumps(post_body))
+  if not Utils.is_success(result['status_code']):
+    raise Exception(f"Failed to create contacts. Result: {result}")
+  return result
+
+
 def update_contact(contact_id, properties):
   post_url = f"{BASE_URL}crm/v3/objects/contacts/{contact_id}?"
   post_body = {
@@ -112,6 +124,17 @@ def update_contact(contact_id, properties):
   return result
 
 
+def update_contacts_batch(contacts):
+  post_url = f"{BASE_URL}crm/v3/objects/contacts/batch/update"
+  post_body = {
+      'inputs': contacts
+  }
+  result = post(post_url, HEADERS, json.dumps(post_body))
+  if not Utils.is_success(result['status_code']):
+    raise Exception(f"Failed to update contacts. Result: {result}")
+  return result
+
+
 def unsubscribe_from_all(contact_email):
   post_url = f"{BASE_URL}email/public/v1/subscriptions/{contact_email}"
   post_body = {
@@ -121,3 +144,15 @@ def unsubscribe_from_all(contact_email):
   if not Utils.is_success(result['status_code']):
     raise Exception(f"Failed to unsubscribe contact. Result: {result}")
   return result
+
+
+def get_contact_properties():
+  return object_properties.get_properties('contacts')
+
+
+def get_contact_property(property_name):
+  return object_properties.get_property('contacts', property_name)
+
+
+def update_contact_property(property_name, data):
+  return object_properties.update_property('contacts', property_name, data)
