@@ -7,7 +7,7 @@ def get_properties(object_type):
   post_url = f"{BASE_URL}crm/v3/properties/{object_type}?archived=false"
   result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
-    raise Exception(f"Failed to retrieve deal. Result: {result}")
+    raise Exception(f"Failed to get properties. Result: {result}")
   return result
 
 
@@ -15,5 +15,13 @@ def get_property(object_type, property_name):
   post_url = f"{BASE_URL}crm/v3/properties/{object_type}/{property_name}?archived=false"
   result = get(post_url, HEADERS)
   if not Utils.is_success(result['status_code']):
-    raise Exception(f"Failed to retrieve deal. Result: {result}")
+    raise Exception(f"Failed to get property. Result: {result}")
+  return result
+
+
+def update_property(object_type, property_name, data):
+  post_url = f"{BASE_URL}crm/v3/properties/{object_type}/{property_name}"
+  result = patch(post_url, HEADERS, payload=data)
+  if not Utils.is_success(result['status_code']):
+    raise Exception(f"Failed to update property. Result: {result}")
   return result
